﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using MDT.Models;
using System.Web.Security;
using WebMatrix.WebData;
using Kendo.Mvc.UI;
using Kendo.Mvc.Extensions;
using System.Data.SqlClient;

namespace MDT.Controllers
{
    public class VehiclesController : Controller
    {
        private MDTDBContext db = new MDTDBContext();

        //
        // GET: /Vehicles/

        public ActionResult Index()
        {
            var vehicles = db.Vehicles 
                .Include(c => c.CarColor);

            return View(vehicles.ToList());
        }

        //
        // GET: /Vehicles/Details/5

        public ActionResult Details(int id = 0)
        {
            Vehicle vehicle = db.Vehicles.Find(id);
            if (vehicle == null)
            {
                return HttpNotFound();
            }
            return View(vehicle);
        }

        //
        // GET: /Vehicles/Create

        public ActionResult Create()
        {

            ViewData["CarMakes"] = new SelectList(db.CarMakes.OrderBy(x => x.Make), "MakeID", "Make");

            ViewData["CarColors"] = new SelectList(db.CarColors.OrderBy(x => x.Color), "ColorID", "Color");

            return View();
        }

        //
        // POST: /Vehicles/Create

        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Create(Vehicle vehicle)
        {

            //Make sure the sticker key has been printed
            if (!IsStickerKeyValid(vehicle.StickerKey))
            {
                ModelState.AddModelError("StickerKey", "The sticker key does not exist.");
            }
            else if (StickerKeyRegistered(vehicle.StickerKey))
            {
                ModelState.AddModelError("StickerKey", "The sticker has already been registered.");
            }


            if (ModelState.IsValid)
            {
                //vehicle.UserID = WebSecurity.GetUserId(User.Identity.Name);
                vehicle.UserID = 1;
                db.Vehicles.Add(vehicle);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            return View(vehicle);
        }

        //Get Models via Filter
        public JsonResult GetCascadeModels(int MakeID)
        {
            var carmodels = db.CarModels.AsQueryable();

            carmodels = carmodels.Where(p => p.MakeID == MakeID);

            return Json(carmodels.Select(p => new { ModelID = p.ModelID, Name = p.Model }), JsonRequestBehavior.AllowGet);
        }

        //
        // GET: /Vehicles/Edit/5

        public ActionResult Edit(int id = 0)
        {
            Vehicle vehicle = db.Vehicles.Find(id);
            if (vehicle == null)
            {
                return HttpNotFound();
            }

            ViewData["CarMakes"] = new SelectList(db.CarMakes, "MakeID", "Make");

            ViewData["CarColors"] = new SelectList(db.CarColors, "ColorID", "Color");
            
            return View(vehicle);

        }

        //
        // POST: /Vehicles/Edit/5

        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Edit(Vehicle vehicle)
        {
            if (ModelState.IsValid)
            {
                db.Entry(vehicle).State = EntityState.Modified;
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            return View(vehicle);
        }

        //
        // GET: /Vehicles/Delete/5

        public ActionResult Delete(int id = 0)
        {
            Vehicle vehicle = db.Vehicles.Find(id);
            if (vehicle == null)
            {
                return HttpNotFound();
            }
            return View(vehicle);
        }

        //
        // POST: /Vehicles/Delete/5

        [HttpPost, ActionName("Delete")]
        [ValidateAntiForgeryToken]
        public ActionResult DeleteConfirmed(int id)
        {
            Vehicle vehicle = db.Vehicles.Find(id);
            db.Vehicles.Remove(vehicle);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }

        //Validate the Sticker Key
        private bool StickerKeyRegistered(string StickerKey) 
        {
            bool myresult = false;

            return myresult;
        }

        private bool IsStickerKeyValid(string StickerKey)
        {

            return true;
        }
    }
}